@@ -1,6 +1,7 @@
 """Reporting related utility functions."""
 import hashlib
 import time
+from datetime import datetime
 from bson.objectid import ObjectId
 from processor.helper.config.config_utils import config_value
 from collections import OrderedDict
@@ -13,8 +14,9 @@ dbname = None
 collection = None
 
 def json_record(container, filetype, filename, json_data=None):
+
     db_record = {
-        "timestamp": int(time.time() * 1000),
+        "timestamp": int(datetime.utcnow().timestamp() * 1000),
         "container": container,
         "checksum": hashlib.md5("{}".encode('utf-8')).hexdigest(),
         "type": filetype,
@@ -32,7 +34,7 @@ def create_output_entry(container, test_file="", filesystem=False):
     od["$schema"] = ""
     od["contentVersion"] = "1.0.0.0"
     od["fileType"] = OUTPUT
-    od["timestamp"] = int(time.time() * 1000)
+    od["timestamp"] = int(datetime.utcnow().timestamp() * 1000)
     od["container"] = container
     od["status"] = "Running"
     dblog = get_dblogger()
@@ -70,7 +72,7 @@ def dump_output_results(results, container, test_file, snapshot, filesystem=True
         od["$schema"] = ""
         od["contentVersion"] = "1.0.0.0"
         od["fileType"] = OUTPUT
-        od["timestamp"] = int(time.time() * 1000)
+        od["timestamp"] = int(datetime.utcnow().timestamp() * 1000)
         od["snapshot"] = snapshot
         od["container"] = container
         dblog = get_dblogger()
